[java-identity-provider COMMIT] in /trunk/idp-session-api/src/main/java/net/shibboleth/idp/session: LogoutPropagation...

noreply at shibboleth.net noreply at shibboleth.net
Tue Oct 27 11:33:57 EDT 2015


Author: scantor
Date: Tue Oct 27 11:33:57 2015
New Revision: 7884

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=7884&view=rev
Log:
Checkstyle.

Added:
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/logic/package-info.java   (with props)
Modified:
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/LogoutPropagationFlowDescriptor.java
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/context/LogoutPropagationContext.java
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/logic/LogoutPropagationFlowDescriptorSelector.java

Modified: trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/LogoutPropagationFlowDescriptor.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/LogoutPropagationFlowDescriptor.java?rev=7884&r1=7883&r2=7884&view=diff
==============================================================================
--- trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/LogoutPropagationFlowDescriptor.java	(original)
+++ trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/LogoutPropagationFlowDescriptor.java	Tue Oct 27 11:33:57 2015
@@ -37,21 +37,31 @@
     /** Type of session handled by this flow. */
     @Nonnull private final Class<? extends SPSession> sessionType;
 
-    /** Constructor. */
-    public LogoutPropagationFlowDescriptor(final Class<? extends SPSession> sessionType) {
-        this.sessionType = Constraint.isNotNull(sessionType, "SessionType cannot be null");
+    /**
+     * Constructor.
+     *
+     * @param type type of {@link SPSession} associated with this flow
+     */
+    public LogoutPropagationFlowDescriptor(final Class<? extends SPSession> type) {
+        sessionType = Constraint.isNotNull(type, "SPSession type cannot be null");
     }
 
-    /** @return The type of session supported by this flow descriptor. */
+    /**
+     * Get the type of {@link SPSession} supported by this flow descriptor.
+     * 
+     * @return type of session supported by this flow descriptor
+     */
     @Nonnull public Class<? extends SPSession> getSessionType() {
         return sessionType;
     }
 
+    /** {@inheritDoc} */
     @Override
     public int hashCode() {
         return getId().hashCode();
     }
 
+    /** {@inheritDoc} */
     @Override
     public boolean equals(Object obj) {
         if (obj == null) {
@@ -69,8 +79,10 @@
         return false;
     }
 
+    /** {@inheritDoc} */
     @Override
     public String toString() {
         return MoreObjects.toStringHelper(this).add("flowId", getId()).toString();
     }
-}
+    
+}

Modified: trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/context/LogoutPropagationContext.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/context/LogoutPropagationContext.java?rev=7884&r1=7883&r2=7884&view=diff
==============================================================================
--- trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/context/LogoutPropagationContext.java	(original)
+++ trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/context/LogoutPropagationContext.java	Tue Oct 27 11:33:57 2015
@@ -1,9 +1,9 @@
 /*
- * Licensed to the University Corporation for Advanced Internet Development,
- * Inc. (UCAID) under one or more contributor license agreements.  See the
+ * Licensed to the University Corporation for Advanced Internet Development, 
+ * Inc. (UCAID) under one or more contributor license agreements.  See the 
  * NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The UCAID licenses this file to You under the Apache
- * License, Version 2.0 (the "License"); you may not use this file except in
+ * copyright ownership. The UCAID licenses this file to You under the Apache 
+ * License, Version 2.0 (the "License"); you may not use this file except in 
  * compliance with the License.  You may obtain a copy of the License at
  *
  *    http://www.apache.org/licenses/LICENSE-2.0
@@ -60,73 +60,94 @@
     @Nonnull @Live private final Map<String, Object> viewMap = new HashMap<>();
 
 
-    /** @return The SP session to be destroyed. */
+    /**
+     * Get the {@link SPSession} being destroyed by the logout propagation.
+     *  
+     * @return the SP session to be destroyed
+     */
     @Nullable public SPSession getSession() {
         return session;
     }
 
     /**
-     * Sets the SP session to be destroyed.
+     * Set the {@link SPSession} to be destroyed.
      *
      * @param session Non-null SP session.
      */
-    public void setSession(@Nonnull final SPSession session) {
-        this.session = Constraint.isNotNull(session, "SPSession cannnot be null");
+    public void setSession(@Nonnull final SPSession theSession) {
+        session = Constraint.isNotNull(theSession, "SPSession cannnot be null");
     }
 
@@ -60,73 +60,94 @@
      *
-     * @param session Non-null SP session.
+     * @param theSession non-null SP session.
      */

[... 153 lines stripped ...]


More information about the commits mailing list